@@ -8,7 +8,7 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ('all' => [ qw(new get_info make_report)]);
 our @EXPORT_OK = (@{$EXPORT_TAGS{'all'}});
 our @EXPORT = qw();
-our $VERSION ='1.1';
+our $VERSION ='1.2';
 #####################################################
 my ($class, $this, $router);
 #####################################################
@@ -44,7 +44,7 @@ sub get_info(){
             if ($_ =~ /ip address/){
                 @split2 = split " ", $_;
                 $address = "$split2[2];$split2[3]" if $split2[3];
-                $address = "no ipv4 address" if !$split2[3];
+                $address = "no ipv4 address;no mask" if !$split2[3];
                 $this->{"Interface ".$interface.";"} = "$address;no description\n" if !$description;
                 $this->{"Interface ".$interface.";"} = "$address;$description\n" if $description;
             }
